@@ -24,6 +24,18 @@ test_that(
     )
   }
 )
+
+test_that(
+  "Function succeeds when called on a dust_list object",
+  {
+    expect_silent(
+      dplyr::group_by(mtcars, am, vs) %>% 
+        dust(ungroup = FALSE) %>% 
+        sprinkle_longtable(longtable = TRUE)
+    )
+  }
+)
+
 # Functional Requirement 2 ------------------------------------------
 
 test_that(
